#/bin/sh
#set -x
UNINSTALL_SDPTool="NO"
INSTALL_SDPTool="NO"
SDPTool_INSTALL_DIR="/usr/local/SDPTool"
SUPPORTED_OS="NO"
RH6_RELEASE=""
RH7_RELEASE=""
CENTOS6_RELEASE=""
CENTOS7_RELEASE=""

print_success()
{
    echo -e "\e[32m======================================="
    echo "Intel(R) SDPTool installed successfully"
    echo -e "=======================================\e[0m"
}

print_installed()
{
    echo -e "\e[34m========================="
    echo "Package already installed"
    echo -e "=========================\e[0m"
}

print_failure()
{
    echo -e "\e[31m==========================="
    echo "Package installation failed"
    echo -e "===========================\e[0m"
}

print_uninstall()
{
    echo "Please uninstall the package and then install"
}

print_refer()
{
    echo "Please refer to the User Guide in the following location :-"
    echo "/usr/share/doc/SDPTool/SDPTool_UserGuide_Rev_1.1.pdf"
    echo "----------------------------------------------------"
    echo "Please refer to the Release Notes in the following location :-"
    echo "/usr/share/doc/SDPTool/ReleaseNotes.txt"
}

show_license()
{ 
    cat Licenses/License.txt | more

    reply=
    while [[ $reply != "Y" && $reply != "y" && $reply != "N" && $reply != "n" ]]; do
	echo "Do you Accept? (Y/N)"
	read reply
    done

    if [[ $reply = "N" || $reply = "n" ]]; then
	exit
    fi
}

check_installed()
{
    if rpm -q --quiet SDPTool ; then 
	print_installed
	return 1
    fi	
    if [ -d "/usr/local/SDPTool" ] ; then
	if [[ $ret ]]; then 
	    return 1
	fi
	print_installed
    fi
} 

echo "Installing SDPTool Package ... "

check_installed
ret=$?
if [ "$ret" -eq 1 ] ; then
	exit 1
else
    if [ -f "/etc/SuSE-release" ] ; then
	OSVer_11=$(grep "VERSION *= *11" /etc/SuSE-release)
	OSVer_12=$(grep "VERSION *= *12" /etc/SuSE-release)
	if [[ $OSVer_11 ]]; then
            ARCH=`uname -m|grep x86_64 > /dev/null 2>&1`
            if [ $? = 0 ] ; then
		rpm -ivh ./RPMS/sles11_x/*.rpm 2>&1 | tee  install.log
            fi
	elif [[ $OSVer_12 ]]; then
	    rpm -ivh ./RPMS/sles12_x/*.rpm 2>&1 | tee  install.log
	fi
    elif [ -f /etc/redhat-release ] || [ -f /etc/centos-release ]; then
	if [ -f /etc/redhat-release ]; then
            RH6_RELEASE=`grep -i "red hat .* release 6.*" /etc/redhat-release`
            RH7_RELEASE=`grep -i "red hat .* release 7.*" /etc/redhat-release`
	fi
	if [ -f /etc/centos-release ]; then
            CENTOS6_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-6.*"` 
            CENTOS7_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-7.*"` 
	fi
	if [[ $RH7_RELEASE ]] ; then 
	    rpm -ivh ./RPMS/rhel7_x/*.rpm 2>&1 | tee install.log
	elif [[ $CENTOS7_RELEASE ]]; then
	    rpm -ivh ./RPMS/centos7_x/*.rpm 2>&1 | tee install.log
	elif [[ $RH6_RELEASE ]]; then
	    rpm -ivh ./RPMS/rhel6_x/*.rpm 2>&1 | tee install.log
	elif [[ $CENTOS6_RELEASE ]] ; then
	    rpm -ivh ./RPMS/centos6_x/*.rpm 2>&1 | tee install.log
	fi
    fi
fi

if [ -d "/usr/local/SDPTool" ] ; then
    print_success
    print_refer
else
    print_failure
    exit 1
fi
exit 0
